@@ -1,5 +1,10 @@
 #![deny(missing_docs)]
 #![allow(missing_docs)] // Contents are self describing for now.
+
+/// An enumeration describing some of the error types emitted by this library.
+///
+/// Most user code should use [`crate::Error`] instead.
+// FIXME: use updated ockam_core::Error...
 #[derive(Clone, Copy, Debug)]
 pub enum OckamError {
     BareError = 1,
@@ -37,7 +42,7 @@ impl From<OckamError> for ockam_core::Error {
     fn from(e: OckamError) -> ockam_core::Error {
         ockam_core::Error::new(
             OckamError::DOMAIN_CODE + (e as u32),
-            OckamError::DOMAIN_NAME,
+            ockam_core::compat::format!("{}::{:?}", module_path!(), e),
         )
     }
 }
